.. include:: ../README.rst
  :end-before: end-of-index-doc

This documentation is mainly split into four parts:

- A tutorial guide, for a complete hands-on approach to restricting existing tokens
- How-to recipes, if you need something specific done
- Discussions, if you want to understand how it works beneath the surface
- Reference guide, to ease integration into your own code

.. toctree::
   :maxdepth: 2

   tutorial
   howto
   discussions
   reference
   contributing
   changelog
